@@ -739,6 +739,11 @@
 # define ID_WIN_SYSMENU_MAPPER 0x0F02
 # define ID_WIN_SYSMENU_CFG_GUI 0x0F03
 # define ID_WIN_SYSMENU_PAUSE 0x0F04
+# define ID_WIN_SYSMENU_RESETSIZE 0x0F05
+#if defined(USE_TTF)
+# define ID_WIN_SYSMENU_TTFINCSIZE 0x0F06
+# define ID_WIN_SYSMENU_TTFDECSIZE 0x0F07
+#endif
 #endif
 #define IDI_MAPPER 0x1000
 #define IDI_CFG_GUI 0x1001
