@@ -16,6 +16,7 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#define VGA_INTERNAL
 
 #include <string.h>
 #include <math.h>
@@ -28,6 +29,7 @@
 #include "render.h"
 #include "mapper.h"
 #include "control.h"
+#include "../ints/int10.h"
 
 #include <output/output_ttf.h>
 
@@ -39,8 +41,6 @@ void ttf_switch_off(bool ss = true);
 /* do not issue CPU-side I/O here -- this code emulates functions that the GDC itself carries out, not on the CPU */
 #include "cpu_io_is_forbidden.h"
 
-#define crtc(blah) vga.crtc.blah
-
 static Bitu read_cga(Bitu /*port*/,Bitu /*iolen*/);
 static void write_cga(Bitu port,Bitu val,Bitu /*iolen*/);
 
@@ -1221,7 +1221,6 @@ Bitu read_herc_status(Bitu /*port*/,Bitu /*iolen*/) {
 }
 
 extern int eurAscii;
-extern uint8_t int10_font_08[256 * 8], int10_font_14[256 * 14], int10_font_16[256 * 16];
 uint8_t euro_08[8] = {
   0x3c, 0x66, 0xfc, 0x60, 0xf8, 0x66, 0x3c, 0x00,
 };
@@ -1235,14 +1234,16 @@ uint8_t euro_16[16] = {
 };
 
 void VGA_SetupOther(void) {
-    if (eurAscii>32 && eurAscii<256) {
-        for (int i=eurAscii*8;i<(eurAscii+1)*8;i++)
-            int10_font_08[i]=euro_08[i%8];
-        for (int i=eurAscii*14;i<(eurAscii+1)*14;i++)
-            int10_font_14[i]=euro_14[i%14];
-        for (int i=eurAscii*16;i<(eurAscii+1)*16;i++)
-            int10_font_16[i]=euro_16[i%16];
-    }
+	if (eurAscii>32 && eurAscii<256) {
+		for (int i=eurAscii*8;i<(eurAscii+1)*8;i++)
+			int10_font_08[i]=euro_08[i%8];
+		for (int i=eurAscii*14;i<(eurAscii+1)*14;i++)
+			int10_font_14[i]=euro_14[i%14];
+		for (int i=eurAscii*16;i<(eurAscii+1)*16;i++)
+			int10_font_16[i]=euro_16[i%16];
+		for (int i=eurAscii*16;i<(eurAscii+1)*16;i++)
+			int10_font_16_mcga[i]=euro_16[i%16];
+	}
 	memset( &vga.tandy, 0, sizeof( vga.tandy ));
 	vga.attr.disabled = 0;
 	vga.config.bytes_skip=0;
