@@ -681,6 +681,7 @@ EXPORT void speex_echo_playback(SpeexEchoState *st, const spx_int16_t *play)
 /** Performs echo cancellation on a frame (deprecated, last arg now ignored) */
 EXPORT void speex_echo_cancel(SpeexEchoState *st, const spx_int16_t *in, const spx_int16_t *far_end, spx_int16_t *out, spx_int32_t *Yout)
 {
+   (void)Yout;//UNUSED
    speex_echo_cancellation(st, in, far_end, out);
 }
 
@@ -1191,6 +1192,7 @@ EXPORT void speex_echo_cancellation(SpeexEchoState *st, const spx_int16_t *in, c
 /* Compute spectrum of estimated echo for use in an echo post-filter */
 void speex_echo_get_residual(SpeexEchoState *st, spx_word32_t *residual_echo, int len)
 {
+   (void)len;//UNUSED
    int i;
    spx_word16_t leak2;
    int N;
