@@ -18,8 +18,9 @@
  * 02110-1301, USA
  */
 
-//#include <glib.h>
-#if !C_FLUIDSYNTH && defined(WIN32)
+#define FLUIDINC
+#include "config.h"
+#if !C_FLUIDSYNTH && defined(WIN32) && !defined(C_HX_DOS)
 #include <fcntl.h>
 
 #include "fluidsynth_priv.h"
