@@ -1,4 +1,6 @@
-#if !C_FLUIDSYNTH && defined(WIN32)
+#define FLUIDINC
+#include "config.h"
+#if !C_FLUIDSYNTH && defined(WIN32) && !defined(C_HX_DOS)
 #include "fluid_lfo.h"
 
 void
