@@ -112,7 +112,7 @@ static inline void QZ_SetFrame(_THIS, NSScreen *nsscreen, NSRect frame)
     [super drawRect:dirtyRect];
     CGSize size = [_text size];
     [[NSColor whiteColor] set];
-    NSRectFill(dirtyRect);
+    NSRectFill(self.bounds);
     [_text drawInRect:CGRectMake(0, 0, size.width, size.height)];
 }
 @end
